@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2021, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2024, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -59,6 +59,7 @@
 */
 
 #include "vsearch.h"
+#include <vector>
 
 /*
   This code implements the method described in this paper:
@@ -73,7 +74,6 @@
 /* global constants/data, no need for synchronization */
 static int parts = 0;
 const int maxparts = 100;
-const int maxparents = 4; /* max, could be fewer */
 const int window = 64;
 const int few = 4;
 const int maxcandidates = few * maxparts;
@@ -140,6 +140,9 @@ struct chimera_info_s
   int * smooth;
   int * maxsmooth;
 
+  double * scan_p;
+  double * scan_q;
+
   int parents_found;
   int best_parents[maxparents];
   int best_start[maxparents];
@@ -166,14 +169,18 @@ void realloc_arrays(struct chimera_info_s * ci)
 {
   if (opt_chimeras_denovo)
     {
-      if (opt_chimeras_parts == 0)
+      if (opt_chimeras_parts == 0) {
         parts = (ci->query_len + maxparts - 1) / maxparts;
-      else
+      }
+      else {
         parts = opt_chimeras_parts;
-      if (parts < 2)
+      }
+      if (parts < 2) {
         parts = 2;
-      else if (parts > maxparts)
+      }
+      else if (parts > maxparts) {
         parts = maxparts;
+      }
     }
   else
     {
@@ -181,7 +188,7 @@ void realloc_arrays(struct chimera_info_s * ci)
       parts = 4;
     }
 
-  int maxhlen = MAX(ci->query_head_len,1);
+  const int maxhlen = MAX(ci->query_head_len, 1);
   if (maxhlen > ci->head_alloc)
     {
       ci->head_alloc = maxhlen;
@@ -190,8 +197,8 @@ void realloc_arrays(struct chimera_info_s * ci)
 
   /* realloc arrays based on query length */
 
-  int maxqlen = MAX(ci->query_len, 1);
-  int maxpartlen = (maxqlen + parts - 1) / parts;
+  const int maxqlen = MAX(ci->query_len, 1);
+  const int maxpartlen = (maxqlen + parts - 1) / parts;
 
   if (maxqlen > ci->query_alloc)
     {
@@ -199,8 +206,7 @@ void realloc_arrays(struct chimera_info_s * ci)
 
       ci->query_seq = (char*) xrealloc(ci->query_seq, maxqlen + 1);
 
-      for(auto & i
-            : ci->si)
+      for(auto & i: ci->si)
         {
           i.qsequence = (char*) xrealloc(i.qsequence, maxpartlen + 1);
         }
@@ -214,16 +220,21 @@ void realloc_arrays(struct chimera_info_s * ci)
       ci->smooth = (int*) xrealloc(ci->smooth,
                                    maxcandidates * maxqlen * sizeof(int));
 
-      int maxalnlen = maxqlen + 2 * db_getlongestsequence();
+      ci->scan_p = (double *) xrealloc(ci->scan_p,
+                                       (maxqlen + 1) * sizeof(double));
+      ci->scan_q = (double *) xrealloc(ci->scan_q,
+                                       (maxqlen + 1) * sizeof(double));
+
+      const int maxalnlen = maxqlen + 2 * db_getlongestsequence();
       for (int f = 0; f < maxparents ; f++)
         {
-          ci->paln[f] = (char*) xrealloc(ci->paln[f], maxalnlen+1);
+          ci->paln[f] = (char*) xrealloc(ci->paln[f], maxalnlen + 1);
         }
-      ci->qaln = (char*) xrealloc(ci->qaln, maxalnlen+1);
-      ci->diffs = (char*) xrealloc(ci->diffs, maxalnlen+1);
-      ci->votes = (char*) xrealloc(ci->votes, maxalnlen+1);
-      ci->model = (char*) xrealloc(ci->model, maxalnlen+1);
-      ci->ignore = (char*) xrealloc(ci->ignore, maxalnlen+1);
+      ci->qaln = (char*) xrealloc(ci->qaln, maxalnlen + 1);
+      ci->diffs = (char*) xrealloc(ci->diffs, maxalnlen + 1);
+      ci->votes = (char*) xrealloc(ci->votes, maxalnlen + 1);
+      ci->model = (char*) xrealloc(ci->model, maxalnlen + 1);
+      ci->ignore = (char*) xrealloc(ci->ignore, maxalnlen + 1);
     }
 }
 
@@ -262,15 +273,15 @@ void find_matches(struct chimera_info_s * ci)
           switch (op)
             {
             case 'M':
-              for(int k=0; k<run; k++)
+              for(int k = 0; k < run; k++)
                 {
                   if (chrmap_4bit[(int)(qseq[qpos])] &
                       chrmap_4bit[(int)(tseq[tpos])])
                     {
                       ci->match[i * ci->query_len + qpos] = 1;
                     }
-                  qpos++;
-                  tpos++;
+                  ++qpos;
+                  ++tpos;
                 }
               break;
 
@@ -307,10 +318,75 @@ int compare_positions(const void * a, const void * b)
     return 0;
 }
 
+bool scan_matches(struct chimera_info_s * ci,
+                  int * matches,
+                  int len,
+                  double percentage,
+                  int * best_start,
+                  int * best_len)
+{
+  /*
+    Scan matches array of zeros and ones, and find the longest subsequence
+    having a match fraction above or equal to the given percentage (e.g. 2%).
+    Based on an idea of finding the longest positive sum substring:
+    https://stackoverflow.com/questions/28356453/longest-positive-sum-substring
+    If the percentage is 2%, matches are given a score of 2 and mismatches -98.
+  */
+
+  double score_match = percentage;
+  double score_mismatch = percentage - 100.0;
+
+  double * p = ci->scan_p;
+  double * q = ci->scan_q;
+
+  p[0] = 0.0;
+  for (int i = 0; i < len; i++)
+    p[i + 1] = p[i] + (matches[i] ? score_match : score_mismatch);
+
+  q[len] = p[len];
+  for (int i = len - 1; i >= 0; i--)
+    q[i] = MAX(q[i + 1], p[i]);
+
+  int best_i = 0;
+  int best_d = -1;
+  double best_c = -1.0;
+  int i = 1;
+  int j = 1;
+  while (j <= len)
+    {
+      double c = q[j] - p[i - 1];
+      if (c >= 0.0)
+        {
+          int d = j - i + 1;
+          if (d > best_d)
+            {
+              best_i = i;
+              best_d = d;
+              best_c = c;
+            }
+          j += 1;
+        }
+      else
+        {
+          i += 1;
+        }
+    }
+
+  if (best_c >= 0.0)
+    {
+      * best_start = best_i - 1;
+      * best_len = best_d;
+      return true;
+    }
+  else
+    return false;
+}
+
 int find_best_parents_long(struct chimera_info_s * ci)
 {
-  /* find parents with longest perfect match regions,
-     excluding regions matched by previously identified parents */
+  /* Find parents with longest matching regions, without indels, allowing
+     a given percentage of mismatches (specified with --chimeras_diff_pct),
+     and excluding regions matched by previously identified parents. */
 
   find_matches(ci);
 
@@ -322,11 +398,7 @@ int find_best_parents_long(struct chimera_info_s * ci)
       best_parents[f].start = -1;
     }
 
-  bool position_used[ci->query_len];
-  for (int i = 0; i < ci->query_len; i++)
-    {
-      position_used[i] = false;
-    }
+  std::vector<bool> position_used(ci->query_len, false);
 
   int pos_remaining = ci->query_len;
   int parents_found = 0;
@@ -343,29 +415,38 @@ int find_best_parents_long(struct chimera_info_s * ci)
         {
           int start = 0;
           int len = 0;
-
-          for (int j = 0; j < ci->query_len; j++)
+          int j = 0;
+          while (j < ci->query_len)
             {
-              if ((position_used[j] == false) &&
-                  (ci->match[i * ci->query_len + j] == 1) &&
-                  ((len == 0) || (ci->insert[i * ci->query_len + j] == 0)))
+              start = j;
+              len = 0;
+              while ((j < ci->query_len) &&
+                     (! position_used[j]) &&
+                     ((len == 0) || (ci->insert[i * ci->query_len + j] == 0)))
                 {
-                  if (len == 0)
-                    {
-                      start = j;
-                    }
                   len++;
-                  if (len > best_len)
+                  j++;
+                }
+              if (len > best_len)
+                {
+                  int scan_best_start = 0;
+                  int scan_best_len = 0;
+                  if (scan_matches(ci,
+                                   ci->match + i*ci->query_len + start,
+                                   len,
+                                   opt_chimeras_diff_pct,
+                                   & scan_best_start,
+                                   & scan_best_len))
                     {
-                      best_cand = i;
-                      best_start = start;
-                      best_len = len;
+                      if (scan_best_len > best_len)
+                        {
+                          best_cand = i;
+                          best_start = start + scan_best_start;
+                          best_len = scan_best_len;
+                        }
                     }
                 }
-              else
-                {
-                  len = 0;
-                }
+              j++;
             }
         }
 
@@ -374,7 +455,7 @@ int find_best_parents_long(struct chimera_info_s * ci)
           best_parents[f].cand = best_cand;
           best_parents[f].start = best_start;
           best_parents[f].len = best_len;
-          parents_found++;
+          ++parents_found;
 
 #if 0
           if (f == 0)
@@ -421,7 +502,7 @@ int find_best_parents_long(struct chimera_info_s * ci)
     printf("Not covered completely (%d).\n", pos_remaining);
 #endif
 
-  return (parents_found > 1) && (pos_remaining == 0);
+  return (parents_found > 1) and (pos_remaining == 0);
 }
 
 int find_best_parents(struct chimera_info_s * ci)
@@ -436,10 +517,7 @@ int find_best_parents(struct chimera_info_s * ci)
       ci->best_parents[f] = -1;
     }
 
-  bool cand_selected[ci->cand_count];
-
-  for (int i = 0; i < ci->cand_count; i++)
-    cand_selected[i] = false;
+  std::vector<bool> cand_selected(ci->cand_count, false);
 
   for (int f = 0; f < 2; f++)
     {
@@ -475,7 +553,7 @@ int find_best_parents(struct chimera_info_s * ci)
 
       for(int i = 0; i < ci->cand_count; i++)
         {
-          if (! cand_selected[i])
+          if (not cand_selected[i])
             {
               int sum = 0;
               for(int qpos = 0; qpos < ci->query_len; qpos++)
@@ -501,17 +579,15 @@ int find_best_parents(struct chimera_info_s * ci)
 
       /* find parent with the most wins */
 
-      int wins[ci->cand_count];
-      for (int i = 0; i < ci->cand_count; i++)
-        wins[i] = 0;
+      std::vector<int> wins(ci->cand_count, 0);
 
-      for(int qpos = window-1; qpos < ci->query_len; qpos++)
+      for(int qpos = window - 1; qpos < ci->query_len; qpos++)
         {
           if (ci->maxsmooth[qpos] != 0)
             {
-              for(int i=0; i < ci->cand_count; i++)
+              for(int i = 0; i < ci->cand_count; i++)
                 {
-                  if (! cand_selected[i])
+                  if (not cand_selected[i])
                     {
                       int z = i * ci->query_len + qpos;
                       if (ci->smooth[z] == ci->maxsmooth[qpos])
@@ -538,8 +614,9 @@ int find_best_parents(struct chimera_info_s * ci)
 
       /* terminate loop if no parent found */
 
-      if (best_parent_cand[f] < 0)
+      if (best_parent_cand[f] < 0) {
         break;
+      }
 
 #if 0
       printf("Query %d: Best parent (%d) candidate: %d. Wins: %d\n",
@@ -552,7 +629,7 @@ int find_best_parents(struct chimera_info_s * ci)
 
   /* Check if at least 2 candidates selected */
 
-  return (best_parent_cand[0] >= 0) && (best_parent_cand[1] >= 0);
+  return (best_parent_cand[0] >= 0) and (best_parent_cand[1] >= 0);
 }
 
 
@@ -595,7 +672,7 @@ int find_max_alignment_length(struct chimera_info_s * ci)
 
   /* find total alignment length */
   int alnlen = 0;
-  for(int i=0; i < ci->query_len+1; i++)
+  for(int i = 0; i < ci->query_len + 1; i++)
     {
       alnlen += ci->maxi[i];
     }
@@ -647,11 +724,11 @@ void fill_alignment_parents(struct chimera_info_s * ci)
             }
           else
             {
-              for(int x=0; x < run; x++)
+              for(int x = 0; x < run; x++)
                 {
-                  if (!inserted)
+                  if (not inserted)
                     {
-                      for(int y=0; y < ci->maxi[qpos]; y++)
+                      for(int y = 0; y < ci->maxi[qpos]; y++)
                         {
                           *t++ = '-';
                         }
@@ -666,7 +743,7 @@ void fill_alignment_parents(struct chimera_info_s * ci)
                       *t++ = '-';
                     }
 
-                  qpos++;
+                  ++qpos;
                   inserted = 0;
                 }
             }
@@ -674,7 +751,7 @@ void fill_alignment_parents(struct chimera_info_s * ci)
 
       /* add any gaps at the end */
 
-      if (! inserted)
+      if (not inserted)
         {
           for(int x=0; x < ci->maxi[qpos]; x++)
             {
@@ -703,11 +780,11 @@ int eval_parents_long(struct chimera_info_s * ci)
   int m = 0;
   char * q = ci->qaln;
   int qpos = 0;
-  for (int i=0; i < ci->query_len; i++)
+  for (int i = 0; i < ci->query_len; i++)
     {
       if (qpos >= (ci->best_start[m] + ci->best_len[m]))
         m++;
-      for (int j=0; j < ci->maxi[i]; j++)
+      for (int j = 0; j < ci->maxi[i]; j++)
         {
           *q++ = '-';
           *pm++ = 'A' + m;
@@ -715,7 +792,7 @@ int eval_parents_long(struct chimera_info_s * ci)
       *q++ = chrmap_upcase[(int)(ci->query_seq[qpos++])];
       *pm++ = 'A' + m;
     }
-  for (int j=0; j < ci->maxi[ci->query_len]; j++)
+  for (int j = 0; j < ci->maxi[ci->query_len]; j++)
     {
       *q++ = '-';
       *pm++ = 'A' + m;
@@ -728,14 +805,14 @@ int eval_parents_long(struct chimera_info_s * ci)
       unsigned int qsym = chrmap_4bit[(int)(ci->qaln[i])];
       unsigned int psym[maxparents];
       for (int f = 0; f < maxparents; f++)
-	psym[f] = 0;
+        psym[f] = 0;
       for (int f = 0; f < ci->parents_found; f++)
         psym[f] = chrmap_4bit[(int)(ci->paln[f][i])];
 
       /* lower case parent symbols that differ from query */
 
       for (int f = 0; f < ci->parents_found; f++)
-        if (psym[f] && (psym[f] != qsym))
+        if (psym[f] and (psym[f] != qsym))
           ci->paln[f][i] = tolower(ci->paln[f][i]);
 
       /* compute diffs */
@@ -744,18 +821,20 @@ int eval_parents_long(struct chimera_info_s * ci)
 
       bool all_defined = qsym;
       for (int f = 0; f < ci->parents_found; f++)
-        if (!psym[f])
+        if (! psym[f])
           all_defined = false;
 
       if (all_defined)
         {
-          bool parents_equal = true;
-          for (int f = 1; f < ci->parents_found; f++)
-            if (psym[f] != psym[0])
-              parents_equal = false;
-
-          if (! parents_equal)
-            diff = ci->model[i];
+          int z = 0;
+          for (int f = 0; f < ci->parents_found; f++)
+            if (psym[f] == qsym)
+              {
+                diff = 'A' + f;
+                z++;
+              }
+          if (z > 1)
+            diff = ' ';
         }
 
       ci->diffs[i] = diff;
@@ -779,11 +858,11 @@ int eval_parents_long(struct chimera_info_s * ci)
       char qsym = chrmap_4bit[(int)(ci->qaln[i])];
 
       for(int f = 0; f < ci->parents_found; f++)
-	{
-	  char psym = chrmap_4bit[(int)(ci->paln[f][i])];
-	  if (qsym == psym)
-	    match_QP[f]++;
-	}
+        {
+          char psym = chrmap_4bit[(int)(ci->paln[f][i])];
+          if (qsym == psym)
+            match_QP[f]++;
+        }
     }
 
 
@@ -814,7 +893,7 @@ int eval_parents_long(struct chimera_info_s * ci)
 
   xpthread_mutex_lock(&mutex_output);
 
-  if (opt_alnout && (status == 4))
+  if (opt_alnout and (status == 4))
     {
       fprintf(fp_uchimealns, "\n");
       fprintf(fp_uchimealns, "----------------------------------------"
@@ -978,7 +1057,7 @@ int eval_parents(struct chimera_info_s * ci)
 
   char * q = ci->qaln;
   int qpos = 0;
-  for (int i=0; i < ci->query_len; i++)
+  for (int i = 0; i < ci->query_len; i++)
     {
       for (int j=0; j < ci->maxi[i]; j++)
         {
@@ -986,7 +1065,7 @@ int eval_parents(struct chimera_info_s * ci)
         }
       *q++ = chrmap_upcase[(int)(ci->query_seq[qpos++])];
     }
-  for (int j=0; j < ci->maxi[ci->query_len]; j++)
+  for (int j = 0; j < ci->maxi[ci->query_len]; j++)
     {
       *q++ = '-';
     }
@@ -1027,12 +1106,12 @@ int eval_parents(struct chimera_info_s * ci)
 
       /* lower case parent symbols that differ from query */
 
-      if (p1sym && (p1sym != qsym))
+      if (p1sym and (p1sym != qsym))
         {
           ci->paln[0][i] = tolower(ci->paln[0][i]);
         }
 
-      if (p2sym && (p2sym != qsym))
+      if (p2sym and (p2sym != qsym))
         {
           ci->paln[1][i] = tolower(ci->paln[1][i]);
         }
@@ -1041,7 +1120,7 @@ int eval_parents(struct chimera_info_s * ci)
 
       char diff;
 
-      if (qsym && p1sym && p2sym)
+      if (qsym and p1sym and p2sym)
         {
           if (p1sym == p2sym)
             {
@@ -1088,21 +1167,21 @@ int eval_parents(struct chimera_info_s * ci)
 
   for (int i = 0; i < alnlen; i++)
     {
-      if (!ci->ignore[i])
+      if (not ci->ignore[i])
         {
           char diff = ci->diffs[i];
 
           if (diff == 'A')
             {
-              sumA++;
+              ++sumA;
             }
           else if (diff == 'B')
             {
-              sumB++;
+              ++sumB;
             }
           else if (diff != ' ')
             {
-              sumN++;
+              ++sumN;
             }
         }
 
@@ -1126,32 +1205,34 @@ int eval_parents(struct chimera_info_s * ci)
   int best_left_a = 0;
   int best_right_a = 0;
 
-  for (int i=0; i<alnlen; i++)
+  for (int i = 0; i < alnlen; i++)
     {
-      if(!ci->ignore[i])
+      if(not ci->ignore[i])
         {
           char diff = ci->diffs[i];
           if (diff != ' ')
             {
               if (diff == 'A')
                 {
-                  left_y++;
-                  right_n--;
+                  ++left_y;
+                  --right_n;
                 }
               else if (diff == 'B')
                 {
-                  left_n++;
-                  right_y--;
+                  ++left_n;
+                  --right_y;
                 }
               else
                 {
-                  left_a++;
-                  right_a--;
+                  ++left_a;
+                  --right_a;
                 }
 
-              double left_h, right_h, h;
+              double left_h = 0;
+              double right_h = 0;
+              double h = 0;
 
-              if ((left_y > left_n) && (right_y > right_n))
+              if ((left_y > left_n) and (right_y > right_n))
                 {
                   left_h = left_y / (opt_xn * (left_n + opt_dn) + left_a);
                   right_h = right_y / (opt_xn * (right_n + opt_dn) + right_a);
@@ -1170,7 +1251,7 @@ int eval_parents(struct chimera_info_s * ci)
                       best_right_a = right_a;
                     }
                 }
-              else if ((left_n > left_y) && (right_n > right_y))
+              else if ((left_n > left_y) and (right_n > right_y))
                 {
                   /* swap left/right and yes/no */
 
@@ -1286,7 +1367,7 @@ int eval_parents(struct chimera_info_s * ci)
 
       for(int i = 0; i < alnlen; i++)
         {
-          if (! ci->ignore[i])
+          if (not ci->ignore[i])
             {
               cols++;
 
@@ -1331,9 +1412,10 @@ int eval_parents(struct chimera_info_s * ci)
       int sumL = best_left_n + best_left_a + best_left_y;
       int sumR = best_right_n + best_right_a + best_right_y;
 
-      if (opt_uchime2_denovo || opt_uchime3_denovo)
+      if (opt_uchime2_denovo or opt_uchime3_denovo)
         {
-          if ((QM == 100.0) && (QT < 100.0))
+          // fix -Wfloat-equal: if match_QM == cols, then QM == 100.0
+          if ((match_QM == cols) and (QT < 100.0))
             {
               status = 4;
             }
@@ -1342,8 +1424,8 @@ int eval_parents(struct chimera_info_s * ci)
         if (best_h >= opt_minh)
           {
             status = 3;
-            if ((divdiff >= opt_mindiv) &&
-                (sumL >= opt_mindiffs) &&
+            if ((divdiff >= opt_mindiv) and
+                (sumL >= opt_mindiffs) and
                 (sumR >= opt_mindiffs))
               {
                 status = 4;
@@ -1354,7 +1436,7 @@ int eval_parents(struct chimera_info_s * ci)
 
       xpthread_mutex_lock(&mutex_output);
 
-      if (opt_uchimealns && (status == 4))
+      if (opt_uchimealns and (status == 4))
         {
           fprintf(fp_uchimealns, "\n");
           fprintf(fp_uchimealns, "----------------------------------------"
@@ -1534,6 +1616,7 @@ int eval_parents(struct chimera_info_s * ci)
   return status;
 }
 
+// refactoring: enum struct status {};
 /*
   new chimeric status:
   0: no parents, non-chimeric
@@ -1633,6 +1716,8 @@ void chimera_thread_init(struct chimera_info_s * ci)
   ci->votes = nullptr;
   ci->model = nullptr;
   ci->ignore = nullptr;
+  ci->scan_p = nullptr;
+  ci->scan_q = nullptr;
 
   for (int f = 0; f < maxparents; f++)
     {
@@ -1717,6 +1802,14 @@ void chimera_thread_exit(struct chimera_info_s * ci)
     {
       xfree(ci->query_head);
     }
+  if (ci->scan_p)
+    {
+      xfree(ci->scan_p);
+    }
+  if (ci->scan_q)
+    {
+      xfree(ci->scan_q);
+    }
 
   for (int f = 0; f < maxparents; f++)
     if (ci->paln[f])
@@ -1758,7 +1851,7 @@ uint64_t chimera_thread_core(struct chimera_info_s * ci)
 
       if (opt_uchime_ref)
         {
-          if (fasta_next(query_fasta_h, ! opt_notrunclabels,
+          if (fasta_next(query_fasta_h, not opt_notrunclabels,
                          chrmap_no_change))
             {
               ci->query_head_len = fasta_get_header_length(query_fasta_h);
@@ -1816,13 +1909,13 @@ uint64_t chimera_thread_core(struct chimera_info_s * ci)
 
       if (ci->query_len >= parts)
         {
-          for (int i=0; i<parts; i++)
+          for (int i = 0; i < parts; i++)
             {
               struct hit * hits;
               int hit_count;
-              search_onequery(ci->si+i, opt_qmask);
-              search_joinhits(ci->si+i, nullptr, & hits, & hit_count);
-              for(int j=0; j<hit_count; j++)
+              search_onequery(ci->si + i, opt_qmask);
+              search_joinhits(ci->si + i, nullptr, & hits, & hit_count);
+              for(int j = 0; j < hit_count; j++)
                 {
                   if (hits[j].accepted)
                     {
@@ -1833,7 +1926,7 @@ uint64_t chimera_thread_core(struct chimera_info_s * ci)
             }
         }
 
-      for(int i=0; i < allhits_count; i++)
+      for(int i = 0; i < allhits_count; i++)
         {
           unsigned int target = allhits_list[i].target;
 
@@ -1875,7 +1968,7 @@ uint64_t chimera_thread_core(struct chimera_info_s * ci)
                ci->snwgaps,
                ci->nwcigar);
 
-      for(int i=0; i < ci->cand_count; i++)
+      for(int i = 0; i < ci->cand_count; i++)
         {
           int64_t target = ci->cand_list[i];
           int64_t nwscore = ci->snwscore[i];
@@ -2021,7 +2114,7 @@ uint64_t chimera_thread_core(struct chimera_info_s * ci)
           nonchimera_abundance += ci->query_size;
 
           /* output no parents, no chimeras */
-          if ((status < 2) && opt_uchimeout)
+          if ((status < 2) and opt_uchimeout)
             {
               fprintf(fp_uchimeout, "0.0000\t");
 
@@ -2067,13 +2160,13 @@ uint64_t chimera_thread_core(struct chimera_info_s * ci)
       if (status < 3)
         {
           /* uchime_denovo: add non-chimeras to db */
-          if (opt_uchime_denovo || opt_uchime2_denovo || opt_uchime3_denovo || opt_chimeras_denovo)
+          if (opt_uchime_denovo or opt_uchime2_denovo or opt_uchime3_denovo or opt_chimeras_denovo)
             {
               dbindex_addsequence(seqno, opt_qmask);
             }
         }
 
-      for (int i=0; i < ci->cand_count; i++)
+      for (int i = 0; i < ci->cand_count; i++)
         {
           if (ci->nwcigar[i])
             {
@@ -2120,14 +2213,14 @@ void chimera_threads_run()
   xpthread_attr_setdetachstate(&attr, PTHREAD_CREATE_JOINABLE);
 
   /* create worker threads */
-  for(int64_t t=0; t<opt_threads; t++)
+  for(int64_t t = 0; t < opt_threads; t++)
     {
-      xpthread_create(pthread+t, & attr,
+      xpthread_create(pthread + t, & attr,
                       chimera_thread_worker, (void*)t);
     }
 
   /* finish worker threads */
-  for(int t=0; t<opt_threads; t++)
+  for(int t = 0; t < opt_threads; t++)
     {
       xpthread_join(pthread[t], nullptr);
     }
@@ -2140,7 +2233,7 @@ void open_chimera_file(FILE * * f, char * name)
   if (name)
     {
       *f = fopen_output(name);
-      if (!*f)
+      if (! *f)
         {
           fatal("Unable to open file %s for writing", name);
         }
@@ -2232,7 +2325,7 @@ void chimera()
             {
               dust_all();
             }
-          else if ((opt_dbmask == MASK_SOFT) && (opt_hardmask))
+          else if ((opt_dbmask == MASK_SOFT) and (opt_hardmask))
             {
               hardmask_all();
             }
@@ -2271,7 +2364,7 @@ void chimera()
         {
           dust_all();
         }
-      else if ((opt_qmask == MASK_SOFT) && (opt_hardmask))
+      else if ((opt_qmask == MASK_SOFT) and (opt_hardmask))
         {
           hardmask_all();
         }
@@ -2283,13 +2376,36 @@ void chimera()
 
   if (opt_log)
     {
-      fprintf(fp_log, "%8.2f  minh\n", opt_minh);
-      fprintf(fp_log, "%8.2f  xn\n", opt_xn);
-      fprintf(fp_log, "%8.2f  dn\n", opt_dn);
-      fprintf(fp_log, "%8.2f  xa\n", 1.0);
-      fprintf(fp_log, "%8.2f  mindiv\n", opt_mindiv);
+      if (opt_uchime_ref || opt_uchime_denovo)
+        {
+          fprintf(fp_log, "%8.2f  minh\n", opt_minh);
+        }
+
+      if (opt_uchime_ref ||
+          opt_uchime_denovo ||
+          opt_uchime2_denovo ||
+          opt_uchime3_denovo)
+        {
+          fprintf(fp_log, "%8.2f  xn\n", opt_xn);
+          fprintf(fp_log, "%8.2f  dn\n", opt_dn);
+          fprintf(fp_log, "%8.2f  xa\n", 1.0);
+        }
+
+      if (opt_uchime_ref || opt_uchime_denovo)
+        {
+          fprintf(fp_log, "%8.2f  mindiv\n", opt_mindiv);
+        }
+
       fprintf(fp_log, "%8.2f  id\n", opt_id);
-      fprintf(fp_log, "%8d  maxp\n", 2);
+
+      if (opt_uchime_ref ||
+          opt_uchime_denovo ||
+          opt_uchime2_denovo ||
+          opt_uchime3_denovo)
+        {
+          fprintf(fp_log, "%8d  maxp\n", 2);
+        }
+
       fprintf(fp_log, "\n");
     }
 
@@ -2300,7 +2416,7 @@ void chimera()
 
   progress_done();
 
-  if (!opt_quiet)
+  if (! opt_quiet)
     {
       if (total_count > 0)
         {
