@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2021, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2024, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -430,7 +430,7 @@ void cluster_core_results_hit(struct hit * best,
     {
       results_show_uc_one(fp_uc,
                           best, query_head,
-                          qsequence, qseqlen, qsequence_rc,
+                          qseqlen,
                           clusterno);
     }
 
@@ -438,14 +438,14 @@ void cluster_core_results_hit(struct hit * best,
     {
       results_show_alnout(fp_alnout,
                           best, 1, query_head,
-                          qsequence, qseqlen, qsequence_rc);
+                          qsequence, qseqlen);
     }
 
   if (fp_samout)
     {
       results_show_samout(fp_samout,
                           best, 1, query_head,
-                          qsequence, qseqlen, qsequence_rc);
+                          qsequence, qsequence_rc);
     }
 
   if (fp_fastapairs)
@@ -454,7 +454,6 @@ void cluster_core_results_hit(struct hit * best,
                                   best,
                                   query_head,
                                   qsequence,
-                                  qseqlen,
                                   qsequence_rc);
     }
 
@@ -471,11 +470,7 @@ void cluster_core_results_hit(struct hit * best,
   if (fp_tsegout)
     {
       results_show_tsegout_one(fp_tsegout,
-                               best,
-                               query_head,
-                               qsequence,
-                               qseqlen,
-                               qsequence_rc);
+                               best);
     }
 
   if (fp_userout)
@@ -487,7 +482,7 @@ void cluster_core_results_hit(struct hit * best,
   if (fp_blast6out)
     {
       results_show_blast6out_one(fp_blast6out, best, query_head,
-                                 qsequence, qseqlen, qsequence_rc);
+                                 qseqlen);
     }
 
   if (opt_matched)
@@ -551,7 +546,7 @@ void cluster_core_results_nohit(int clusterno,
       if (fp_blast6out)
         {
           results_show_blast6out_one(fp_blast6out, nullptr, query_head,
-                                     qsequence, qseqlen, qsequence_rc);
+                                     qseqlen);
         }
     }
 
