@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2022, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2024, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -117,20 +117,30 @@ double find_median()
             }
         }
 
-      double mid = below_count + cand_count + above_count;
-      if (mid == 0)
+      if (below_count + cand_count + above_count == 0U) // fix -Wfloat-equal
         return 0;
-      mid = mid / 2.0;
 
-      if (mid >= below_count)
+      if (above_count + cand_count >= below_count)
+        // mid >= below_count
         {
-          if (mid <= below_count + cand_count)
+          if (above_count <= below_count + cand_count)
+            // mid <= below_count + cand_count
             {
-              if (mid == below_count + cand_count)
+              if (above_count == below_count + cand_count)
+                // mid == below_count + cand_count
+                // same as:
+                // (below_count + cand_count + above_count) / 2 == below_count + cand_count
+                // which simplifies into:
+                // above_count == below_count + cand_count
                 {
                   return (cand + above) / 2.0;
                 }
-              else if (mid == below_count)
+              else if (above_count + cand_count == below_count)
+                // mid == below_count
+                // same as:
+                // (below_count + cand_count + above_count) / 2 == below_count
+                // which simplifies into:
+                // above_count + cand_count == below_count
                 {
                   return (below + cand) / 2.0;
                 }
@@ -233,7 +243,7 @@ void derep_smallmem(char * input_filename)
     }
   else
     {
-      fatal("Ouput file for dereplication must be specified with --fastaout");
+      fatal("Output file for dereplication must be specified with --fastaout");
     }
 
   uint64_t filesize = fastx_get_size(h);
@@ -412,8 +422,8 @@ void derep_smallmem(char * input_filename)
       if (sequencecount > 0)
         {
           fprintf(stderr,
-                  "%'" PRIu64 " nt in %'" PRIu64 " seqs, min %'" PRIu64
-                  ", max %'" PRIu64 ", avg %'.0f\n",
+                  "%" PRIu64 " nt in %" PRIu64 " seqs, min %" PRIu64
+                  ", max %" PRIu64 ", avg %.0f\n",
                   nucleotidecount,
                   sequencecount,
                   shortest,
@@ -423,7 +433,7 @@ void derep_smallmem(char * input_filename)
       else
         {
           fprintf(stderr,
-                  "%'" PRIu64 " nt in %'" PRIu64 " seqs\n",
+                  "%" PRIu64 " nt in %" PRIu64 " seqs\n",
                   nucleotidecount,
                   sequencecount);
         }
@@ -434,8 +444,8 @@ void derep_smallmem(char * input_filename)
       if (sequencecount > 0)
         {
           fprintf(fp_log,
-                  "%'" PRIu64 " nt in %'" PRIu64 " seqs, min %'" PRIu64
-                  ", max %'" PRIu64 ", avg %'.0f\n",
+                  "%" PRIu64 " nt in %" PRIu64 " seqs, min %" PRIu64
+                  ", max %" PRIu64 ", avg %.0f\n",
                   nucleotidecount,
                   sequencecount,
                   shortest,
@@ -445,7 +455,7 @@ void derep_smallmem(char * input_filename)
       else
         {
           fprintf(fp_log,
-                  "%'" PRIu64 " nt in %'" PRIu64 " seqs\n",
+                  "%" PRIu64 " nt in %" PRIu64 " seqs\n",
                   nucleotidecount,
                   sequencecount);
         }
