@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2021, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2024, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -59,6 +59,8 @@
 */
 
 #include "vsearch.h"
+#include <algorithm>  // std::max
+
 
 inline int fastq_get_qual_eestats(char q)
 {
@@ -476,7 +478,10 @@ void fastq_eestats2()
       if (len > longest)
         {
           longest = len;
-          int new_len_steps = 1 + MAX(0, (MIN(longest, (uint64_t)opt_length_cutoffs_longest) - opt_length_cutoffs_shortest) / opt_length_cutoffs_increment);
+          // opt_length_cutoffs_longest is an int between 1 and INT_MAX
+          int high = MIN(longest, (uint64_t)(opt_length_cutoffs_longest));
+          int new_len_steps = 1 + MAX(0, ((high - opt_length_cutoffs_shortest)
+                                          / opt_length_cutoffs_increment));
 
           if (new_len_steps > len_steps)
             {
