@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2021, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2024, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -59,6 +59,7 @@
 */
 
 #include "vsearch.h"
+#include <vector>
 
 /* chunk constants */
 
@@ -281,19 +282,28 @@ inline int get_qual(char q)
   return qual;
 }
 
-inline double q_to_p(int q)
+
+inline auto q_to_p(int quality_symbol) -> double
 {
-  int x = q - opt_fastq_ascii;
-  if (x < 2)
-    {
-      return 0.75;
-    }
-  else
-    {
-      return exp10(-x/10.0);
-    }
+  static constexpr int low_quality_threshold = 2;
+  static constexpr double max_probability = 0.75;
+  static constexpr double quality_divider = 10.0;
+  static constexpr double power_base = 10.0;
+
+  assert(quality_symbol >= 33);
+  assert(quality_symbol <= 126);
+
+  const auto quality_value = static_cast<int>(quality_symbol - opt_fastq_ascii);
+
+  // refactor: extract branch to a separate operation
+  if (quality_value < low_quality_threshold) {
+    return max_probability;
+  }
+  // probability = 10^-(quality / 10)
+  return std::pow(power_base, -quality_value / quality_divider);
 }
 
+
 void precompute_qual()
 {
   /* Precompute tables of scores etc */
@@ -691,10 +701,10 @@ int64_t optimize(merge_data_t * ip,
 
   int kmers = 0;
 
-  int diags[ip->fwd_trunc + ip->rev_trunc];
+  std::vector<int> diags(ip->fwd_trunc + ip->rev_trunc, 0);
 
   kh_insert_kmers(kmerhash, k, ip->fwd_sequence, ip->fwd_trunc);
-  kh_find_diagonals(kmerhash, k, ip->rev_sequence, ip->rev_trunc, diags);
+  kh_find_diagonals(kmerhash, k, ip->rev_sequence, ip->rev_trunc, diags.data());
 
   for(int64_t i = i1; i <= i2; i++)
     {
