@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2021, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2024, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -64,7 +64,6 @@ void results_show_fastapairs_one(FILE * fp,
                                  struct hit * hp,
                                  char * query_head,
                                  char * qsequence,
-                                 int64_t qseqlen,
                                  char * rc)
 {
   /* http://www.drive5.com/usearch/manual/fastapairs.html */
@@ -144,11 +143,7 @@ void results_show_qsegout_one(FILE * fp,
 }
 
 void results_show_tsegout_one(FILE * fp,
-                              struct hit * hp,
-                              char * query_head,
-                              char * qsequence,
-                              int64_t qseqlen,
-                              char * rc)
+                              struct hit * hp)
 {
   if (hp)
     {
@@ -176,9 +171,7 @@ void results_show_tsegout_one(FILE * fp,
 void results_show_blast6out_one(FILE * fp,
                                 struct hit * hp,
                                 char * query_head,
-                                char * qsequence,
-                                int64_t qseqlen,
-                                char * rc)
+                                int64_t qseqlen)
 {
 
   /*
@@ -242,9 +235,7 @@ void results_show_blast6out_one(FILE * fp,
 void results_show_uc_one(FILE * fp,
                          struct hit * hp,
                          char * query_head,
-                         char * qsequence,
                          int64_t qseqlen,
-                         char * rc,
                          int clusterno)
 {
   /*
@@ -519,10 +510,7 @@ void results_show_userout_one(FILE * fp, struct hit * hp,
 void results_show_lcaout(FILE * fp,
                          struct hit * hits,
                          int hitcount,
-                         char * query_head,
-                         char * qsequence,
-                         int64_t qseqlen,
-                         char * rc)
+                         char * query_head)
 {
   /* Output last common ancestor (LCA) of the hits,
      in a similar way to the Sintax command */
@@ -665,8 +653,7 @@ void results_show_alnout(FILE * fp,
                          int hitcount,
                          char * query_head,
                          char * qsequence,
-                         int64_t qseqlen,
-                         char * rc)
+                         int64_t qseqlen)
 {
   /* http://drive5.com/usearch/manual/alnout.html */
 
@@ -904,7 +891,6 @@ void results_show_samout(FILE * fp,
                          int hitcount,
                          char * query_head,
                          char * qsequence,
-                         int64_t qseqlen,
                          char * rc)
 {
   /*
