@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2021, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2024, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -63,30 +63,22 @@ void results_show_alnout(FILE * fp,
                          int hitcount,
                          char * query_head,
                          char * qsequence,
-                         int64_t qseqlen,
-                         char * rc);
+                         int64_t qseqlen);
 
 void results_show_lcaout(FILE * fp,
                          struct hit * hits,
                          int hitcount,
-                         char * query_head,
-                         char * qsequence,
-                         int64_t qseqlen,
-                         char * rc);
+                         char * query_head);
 
 void results_show_blast6out_one(FILE * fp,
                                 struct hit * hp,
                                 char * query_head,
-                                char * qsequence,
-                                int64_t qseqlen,
-                                char * rc);
+                                int64_t qseqlen);
 
 void results_show_uc_one(FILE * fp,
                          struct hit * hp,
                          char * query_head,
-                         char * qsequence,
                          int64_t qseqlen,
-                         char * rc,
                          int clusterno);
 
 void results_show_userout_one(FILE * fp,
@@ -100,7 +92,6 @@ void results_show_fastapairs_one(FILE * fp,
                                  struct hit * hp,
                                  char * query_head,
                                  char * qsequence,
-                                 int64_t qseqlen,
                                  char * rc);
 
 void results_show_qsegout_one(FILE * fp,
@@ -111,11 +102,7 @@ void results_show_qsegout_one(FILE * fp,
                               char * rc);
 
 void results_show_tsegout_one(FILE * fp,
-                              struct hit * hp,
-                              char * query_head,
-                              char * qsequence,
-                              int64_t qseqlen,
-                              char * rc);
+                              struct hit * hp);
 
 void results_show_samheader(FILE * fp,
                             char * cmdline,
@@ -126,5 +113,4 @@ void results_show_samout(FILE * fp,
                          int hitcount,
                          char * query_head,
                          char * qsequence,
-                         int64_t qseqlen,
                          char * rc);
