@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2021, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2024, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -83,6 +83,7 @@
 #include <map>
 #include <set>
 #include <string>
+#include <cassert>
 
 /* include appropriate regex library */
 
@@ -392,6 +393,7 @@ extern char * opt_usearch_global;
 extern char * opt_userout;
 extern double * opt_ee_cutoffs_values;
 extern double opt_abskew;
+extern double opt_chimeras_diff_pct;
 extern double opt_dn;
 extern double opt_fastq_maxdiffpct;
 extern double opt_fastq_maxee;
