@@ -2,7 +2,7 @@
 
   VSEARCH: a versatile open source tool for metagenomics
 
-  Copyright (C) 2014-2021, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
+  Copyright (C) 2014-2024, Torbjorn Rognes, Frederic Mahe and Tomas Flouri
   All rights reserved.
 
   Contact: Torbjorn Rognes <torognes@ifi.uio.no>,
@@ -110,7 +110,7 @@ class xstring
 
   void add_c(char c)
   {
-    size_t needed = 1;
+    const size_t needed = 1;
     if (length + needed + 1 > alloc)
       {
         alloc = length + needed + 1;
@@ -123,7 +123,7 @@ class xstring
 
   void add_d(int d)
   {
-    int needed = snprintf(nullptr, 0, "%d", d);
+    const int needed = snprintf(nullptr, 0, "%d", d);
     if (needed < 0)
       {
         fatal("snprintf failed");
@@ -140,7 +140,7 @@ class xstring
 
   void add_s(char * s)
   {
-    size_t needed = strlen(s);
+    const size_t needed = strlen(s);
     if (length + needed + 1 > alloc)
       {
         alloc = length + needed + 1;
